.. _oorzaak:

oorzaak
#######

| stimuleer prolactine productie.
| verstoort temperatuurregeling.
| veroorzaakt extrapiramidale symptomen.
| veroorzaakt neurolepticumsyndroom (NMS).
| geeft kans op onder andere orthostatische hypotensie, reflextachycardie en miosis.
| veroorzaakt depressie van het centrale zenuwstelsel.
| veroorzaakt anticholinerge effecten, zoals agitatie, hallucinaties, delier, tachycardie, mydriasis, wazig zicht, droge huid en slijmvliezen, ileus en urineretentie.
| veroorzaakt mogelijk myocardiale depressie en dysritmieën.
